Module: Lutaml::UmlRepository::Repository::Deprecated

Included in:
Lutaml::UmlRepository::Repository
Defined in:
lib/lutaml/uml_repository/repository/deprecated.rb

Overview

Deprecated API methods kept for backward compatibility.

These methods delegate to the current API but are marked for removal in a future major version. Include this module to maintain backward compatibility with older callers.

Instance Method Summary collapse

Instance Method Details

#export(output_path, options = {}) ⇒ Object



33
34
35
# File 'lib/lutaml/uml_repository/repository/deprecated.rb', line 33

def export(output_path, options = {})
  export_to_package(output_path, options)
end

#find_associations(class_or_qname, options = {}) ⇒ Object



23
24
25
# File 'lib/lutaml/uml_repository/repository/deprecated.rb', line 23

def find_associations(class_or_qname, options = {})
  associations_of(class_or_qname, options)
end

#find_children(class_or_qname, recursive: false) ⇒ Object



18
19
20
# File 'lib/lutaml/uml_repository/repository/deprecated.rb', line 18

def find_children(class_or_qname, recursive: false)
  subtypes_of(class_or_qname, recursive: recursive)
end

#find_diagrams(package_path) ⇒ Object



28
29
30
# File 'lib/lutaml/uml_repository/repository/deprecated.rb', line 28

def find_diagrams(package_path)
  diagrams_in_package(package_path)
end

#search_classes(query_string) ⇒ Object

Deprecated.

Use Lutaml::UmlRepository::Repository#search with types: [:class] instead



13
14
15
# File 'lib/lutaml/uml_repository/repository/deprecated.rb', line 13

def search_classes(query_string)
  search(query_string, types: [:class])[:classes]
end